pub struct Entry<V: Version> { /* private fields */ }Expand description
MMR Entry.
Implementations
Sourceimpl<V: Version> Entry<V>
impl<V: Version> Entry<V>
Sourcepub fn new(data: V::NodeData, left: EntryLink, right: EntryLink) -> Self
pub fn new(data: V::NodeData, left: EntryLink, right: EntryLink) -> Self
New entry of type node.
Sourcepub fn leaf_count(&self) -> u64
pub fn leaf_count(&self) -> u64
Number of leaves under this node.
Panics
Panics if this entry was constructed with a descending height range or
a range containing more leaves than can be represented by a u64.
Entries produced by Self::read are validated against these cases.