pub enum V3 {}Expand description
Version 3 of the Zcash chain history tree.
This version is used from the NU6.3 epoch for history nodes that include Ironwood shielded pool metadata. Earlier epochs continue to use the corresponding earlier history tree versions.