pub struct NodeDataV3 {
pub v2: V2,
pub start_ironwood_root: [u8; 32],
pub end_ironwood_root: [u8; 32],
pub ironwood_tx: u64,
}Expand description
V3 node metadata.
This extends the NU5 history node format with metadata for the Ironwood shielded pool. Ironwood uses an Orchard-shaped note commitment tree, but is represented as a distinct pool in chain history.
Fields
v2: V2The V2 node data retained in V3.
start_ironwood_root: [u8; 32]Ironwood tree root at the start of this node’s interval.
Leaf nodes represent a single block, so their start and end roots are both the final Ironwood note commitment tree root after the corresponding block. Internal nodes carry the start root from their leftmost leaf.
end_ironwood_root: [u8; 32]Ironwood tree root at the end of this node’s interval.
Leaf nodes represent a single block, so their start and end roots are both the final Ironwood note commitment tree root after the corresponding block. Internal nodes carry the end root from their rightmost leaf.
ironwood_tx: u64Number of transactions containing an Ironwood bundle.